[spi_device] Waive warning about unused cmd_info_t::opcode field

We were already waiving messages about addr_en, addr_swap_en and
addr_4b_affected, but 88b4b13 added another field which falls in the
same bucket.

Signed-off-by: Rupert Swarbrick <rswarbrick@lowrisc.org>
diff --git a/hw/ip/spi_device/rtl/spi_passthrough.sv b/hw/ip/spi_device/rtl/spi_passthrough.sv
index ce8088d..3b38131 100644
--- a/hw/ip/spi_device/rtl/spi_passthrough.sv
+++ b/hw/ip/spi_device/rtl/spi_passthrough.sv
@@ -559,12 +559,13 @@
     end
   end
 
   // Some of the fields of cmd_info are used in the big FSM below. The addr_* fields are ignored
   // because we pick them from cmd_info_d instead (in a different FSM state). We rely on the
   // synthesis tool not to generate the unneeded flops but must explicitly waive lint warnings about
   // unused fields.
   logic unused_cmd_info_fields;
   assign unused_cmd_info_fields = &{1'b0,
+                                    cmd_info.opcode,
                                     cmd_info.addr_en,
                                     cmd_info.addr_swap_en,
                                     cmd_info.addr_4b_affected,
@@ -559,12 +559,13 @@
   end
 
-  // Some of the fields of cmd_info are used in the big FSM below. The addr_* fields are ignored
-  // because we pick them from cmd_info_d instead (in a different FSM state). We rely on the
-  // synthesis tool not to generate the unneeded flops but must explicitly waive lint warnings about
-  // unused fields.
+  // Some of the fields of cmd_info are used in the big FSM below. The opcode field and the addr_*
+  // fields are ignored because we pick them from cmd_info_d instead (in a different FSM state). We
+  // rely on the synthesis tool not to generate the unneeded flops but must explicitly waive lint
+  // warnings about unused fields.
   logic unused_cmd_info_fields;
   assign unused_cmd_info_fields = &{1'b0,